@@ -20,6 +20,7 @@ from cloudinit.url_helper import (
     dual_stack,
     oauth_headers,
     read_file_or_url,
+    readurl,
     wait_for_url,
 )
 from tests.unittests.helpers import CiTestCase, mock, skipIf
@@ -152,6 +153,11 @@ class TestReadFileOrUrl(CiTestCase):
 
         m_response = mock.MagicMock()
 
+        class FakeSessionRaisesHttpError(requests.Session):
+            @classmethod
+            def request(cls, **kwargs):
+                raise requests.exceptions.HTTPError("broke")
+
         class FakeSession(requests.Session):
             @classmethod
             def request(cls, **kwargs):
@@ -171,8 +177,10 @@ class TestReadFileOrUrl(CiTestCase):
                 return m_response
 
         with mock.patch(M_PATH + "requests.Session") as m_session:
-            error = requests.exceptions.HTTPError("broke")
-            m_session.side_effect = [error, FakeSession()]
+            m_session.side_effect = [
+                FakeSessionRaisesHttpError(),
+                FakeSession(),
+            ]
             # assert no retries and check_status == True
             with self.assertRaises(UrlError) as context_manager:
                 response = read_file_or_url(url)
@@ -275,6 +283,71 @@ def assert_time(func, max_time=1):
     return out
 
 
+class TestReadUrl:
+    @pytest.mark.parametrize("headers", [{}, {"Metadata": "true"}])
+    def test_headers(self, headers):
+        url = "http://hostname/path"
+        m_response = mock.MagicMock()
+
+        expected_headers = headers.copy()
+        expected_headers["User-Agent"] = "Cloud-Init/%s" % (
+            version.version_string()
+        )
+
+        class FakeSession(requests.Session):
+            @classmethod
+            def request(cls, **kwargs):
+                expected_kwargs = {
+                    "url": url,
+                    "allow_redirects": True,
+                    "method": "GET",
+                    "headers": expected_headers,
+                    "stream": False,
+                }
+
+                assert kwargs == expected_kwargs
+                return m_response
+
+        with mock.patch(
+            M_PATH + "requests.Session", side_effect=[FakeSession()]
+        ):
+            response = readurl(url, headers=headers)
+
+        assert response._response == m_response
+
+    @pytest.mark.parametrize("headers", [{}, {"Metadata": "true"}])
+    def test_headers_cb(self, headers):
+        url = "http://hostname/path"
+        m_response = mock.MagicMock()
+
+        expected_headers = headers.copy()
+        expected_headers["User-Agent"] = "Cloud-Init/%s" % (
+            version.version_string()
+        )
+        headers_cb = lambda _: headers
+
+        class FakeSession(requests.Session):
+            @classmethod
+            def request(cls, **kwargs):
+                expected_kwargs = {
+                    "url": url,
+                    "allow_redirects": True,
+                    "method": "GET",
+                    "headers": expected_headers,
+                    "stream": False,
+                }
+
+                assert kwargs == expected_kwargs
+                return m_response
+
+        with mock.patch(
+            M_PATH + "requests.Session", side_effect=[FakeSession()]
+        ):
+            response = readurl(url, headers_cb=headers_cb)
+
+        assert response._response == m_response
+
+
 event = Event()
 
 
@@ -534,7 +607,9 @@ class TestUrlHelper:
         m_sleep = mocker.patch(
             f"{M_PATH}time.sleep", side_effect=self.sleep_side_effect
         )
-        mocker.patch(f"{M_PATH}time.time", side_effect=self.time_side_effect)
+        mocker.patch(
+            f"{M_PATH}time.monotonic", side_effect=self.time_side_effect
+        )
 
         yield m_readurl, m_sleep
 
@@ -588,8 +663,8 @@ class TestUrlHelper:
         # In practice a value such as 0.150 is used
         url, response_contents = wait_for_url(
             urls=addresses,
-            max_wait=1,
-            timeout=1,
+            max_wait=2,
+            timeout=0.3,
             connect_synchronously=False,
             async_delay=0.0,
         )
@@ -684,9 +759,9 @@ class TestUrlHelper:
         assert actual_sleep_times == expected_sleep_times
 
     # These side effect methods are a way of having a somewhat predictable
-    # output for time.time(). Otherwise, we have to track too many calls
-    # to time.time() and unrelated changes to code being called could cause
-    # these tests to fail.
+    # output for time.monotonic(). Otherwise, we have to track too many calls
+    # to time.monotonic() and unrelated changes to code being called could
+    # cause these tests to fail.
     # 0.0000001 is added to simulate additional execution time but keep it
     # small enough for pytest.approx() to work
     def sleep_side_effect(self, sleep_time):
